"""
The qirest unit tests.

:Note: unlike the other qi* python projects, the qirest
  tests are contained within the main qirest package. The test
  module is thus contained in the qirest source distribution.
  This allows other python projects to call the qirest seed
  module to populate a test or demo database.
"""
